Attribute VB_Name = "modAlwaysOnTop"
'///////////////////////////////////////////////////////////////////////////////
'//                                                                           //
'// PROJECT     :                                                             //
'// FILE        : frmFlash.frm                                                //
'// VERSION     : 1.0.0                                                       //
'// CREATED     : ??/06/1997  BY : Roal Zanazzi                               //
'// MODIFIED    : 10/09/1998  BY : Roal Zanazzi                               //
'// LANGUAGE    : Visual Basic (any version)                                  //
'// ENVIRONMENT : Windows                                                     //
'// DESCRIPTION : A function to set/unset a window always on top.             //
'//                                                                           //
'// Copyright  1997-1998 Roal Zanazzi <zrs@iol.it>                           //
'///////////////////////////////////////////////////////////////////////////////
Option Explicit

' API constants declarations.
Const SWP_NOSIZE = &H1
Const SWP_NOMOVE = &H2
Const SWP_NOREDRAW = &H8
Const HWND_TOPMOST = -1
Const HWND_NOTOPMOST = -2

' API function declaration.
Declare Function SetWindowPos Lib "user32" (ByVal hwnd As Long, ByVal hWndInsertAfter As Long, ByVal x As Long, ByVal y As Long, ByVal cx As Long, ByVal cy As Long, ByVal wFlags As Long) As Long


'-------------------------------------------------------------------------------
' FUNCTION    : Window_SetAlwaysOnTop(HWND, Boolean)
' DESCRIPTION : This function will set a window "always on top".
'               WIN32 API function are called to set/unset the window topmost.
'               The window is not resized, moved or altered in any way.
' PARAMETERS  : - hwnd: Long            Window to set alwasy on top.
'               - AlwaysOnTop: Boolean  Flag to set/unset always on top.
' RETURN      : True if the function succeded,
'               False if an error occured and the operation cannot be performed.
' EXAMPLE     : Window_SetAlwaysOnTop Form1.hwnd, True
'-------------------------------------------------------------------------------
Function Window_SetAlwaysOnTop(hwnd As Long, AlwaysOnTop As Boolean) As Boolean
    If AlwaysOnTop Then
        Window_SetAlwaysOnTop = SetWindowPos(hwnd, HWND_TOPMOST, 0, 0, 0, 0, SWP_NOREDRAW Or SWP_NOSIZE Or SWP_NOMOVE)
    Else
        Window_SetAlwaysOnTop = SetWindowPos(hwnd, HWND_NOTOPMOST, 0, 0, 0, 0, SWP_NOREDRAW Or SWP_NOSIZE Or SWP_NOMOVE)
    End If
End Function
